#ifndef SEND_API_CLIENT_H
#define SEND_API_CLIENT_H





/**
 * Initialize the rest API interface
 * @param	client_id			client account identifier - you will get this from linemetrics support
 * @param	client_id_len		Length of the client_id (must not be larger than 32)
 * @param	client_secret		security key - you will get this from linemetrics support
 * @param	client_secret_len	Length of the client_secret (must not be larger than 32)
 * @retVal  val == 1 -> OK, val <= 0 -> FAILED 
 */
int init_rest_api(char * client_id, size_t client_id_len, char * client_secret, size_t client_secret_len);

/**
 * saveDouble on linemetrics application
 * @param	alias		user defined identifier for a measuring point (for example: temperature1) -> (must not be larger than 256)
 * @param	custom_key	system defined custom key -> (must not be larger than 256)
 * @param	value		double-value to store in the linemetrics application
 * @retVal  val == 1 -> OK, val <= 0 -> FAILED  
 */
int saveValue(char *alias, char *custom_key, double value);

/**
 * saveValue on linemetrics application
 * @param	alias		user defined identifier for a measuring point (for example: temperature1) -> (must not be larger than 256)
 * @param	custom_key	system defined custom key -> (must not be larger than 256)
 * @param	dataString		string-value to store in the linemetrics application
 * @retVal  val == 1 -> OK, val <= 0 -> FAILED  
 */
int saveString(char *alias, char *custom_key, char *dataString);

/**
 * saveValue on linemetrics application
 * @param	alias		user defined identifier for a measuring point (for example: temperature1) -> (must not be larger than 256)
 * @param	custom_key	system defined custom key -> (must not be larger than 256)
 * @param	dataBool	int-value(only 0 or 1) to store in the linemetrics application
 * @retVal  val == 1 -> OK, val <= 0 -> FAILED  
 */
int saveBool(char *alias, char *custom_key, int dataBool);

/**
 * saveValue on linemetrics application
 * @param	alias		user defined identifier for a measuring point (for example: temperature1) -> (must not be larger than 256)
 * @param	custom_key	system defined custom key -> (must not be larger than 256)
 * @param	value		double-value to store in the linemetrics application
 * @param	min			min-value to store in the linemetrics application
 * @param	max			max-value to store in the linemetrics application
 * @retVal  val == 1 -> OK, val <= 0 -> FAILED  
 */
int saveDoubleAverage(char *alias, char *custom_key, double value, double min, double max);

/**
 * saveValue on linemetrics application
 * @param	alias		user defined identifier for a measuring point (for example: temperature1) -> (must not be larger than 256)
 * @param	custom_key	system defined custom key -> (must not be larger than 256)
 * @param	lat			lat-value to store in the linemetrics application
 * @param	long		long-value to store in the linemetrics application
 * @retVal  val == 1 -> OK, val <= 0 -> FAILED  
 */
 int saveGeoCoord(char *alias, char *custom_key, double lat, double lng);


/**
 * print error Codes human readable
 * @param	errorCode		return values of the api functions
 */
void printErrorMessages(int errorCode);
#endif
